cgexplore.terms.TargetCosineAngleRange
======================================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetCosineAngleRange
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetCosineAngleRange.yield_angles
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetCosineAngleRange.type1
      ~TargetCosineAngleRange.type2
      ~TargetCosineAngleRange.type3
      ~TargetCosineAngleRange.element1
      ~TargetCosineAngleRange.element2
      ~TargetCosineAngleRange.element3
      ~TargetCosineAngleRange.ns
      ~TargetCosineAngleRange.bs
      ~TargetCosineAngleRange.angle_ks
   
   